﻿using System;
using System.Collections.Generic;
using System.Drawing;
using System.Drawing.Imaging;
using System.IO;
using System.Linq;
using System.Reflection;
using System.Windows;
using Telerik.Windows.Documents.FormatProviders.OpenXml.Docx;
using Telerik.Windows.Documents.Layout;
using Telerik.Windows.Documents.Model;

namespace ImageScaleDemo
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            //Setup RadDocument
            RadDocument document = new RadDocument() { LayoutMode = DocumentLayoutMode.Paged };
            document.SectionDefaultPageSize = PaperTypeConverter.ToSize(PaperTypes.Letter);
            document.SectionDefaultPageOrientation = PageOrientation.Portrait;

            const double pageMarginSizeInches = 0.5;
            int marginSizeDip = (int)Unit.InchToDip(pageMarginSizeInches);
            document.SectionDefaultPageMargin = new Padding(marginSizeDip);

            //Add text and other document content

            AddImageTable(document);

            //add more text and document content//output to .docx file

            //write to .docx file
            using (Stream outStream = new FileStream("out.docx", FileMode.Create))
            {
                DocxFormatProvider provider = new DocxFormatProvider();
                provider.Export(document, outStream);
            }

            this.radRichTextBox.Document = document;

            //end of program
        }

        void AddImageTable(RadDocument document)
        {
            Section section = new Section();
            TableRow row;

            //Stream stream = Application.GetResourceStream(GetResourceUri("Images/telerik-ninja.jpg")).Stream;
            Stream stream = Application.GetResourceStream(GetResourceUri("Images/test.jpg")).Stream;

            System.Drawing.Bitmap testImage = new Bitmap(stream);
            //( a 500 pixel by 500 pixel bitmap image taken of an application window)

            Table table = new Table();

            table.StyleName = RadDocumentDefaultStyles.DefaultTableGridStyleName;
            row = new TableRow();
            TableCell cell = new TableCell() { PreferredWidth = new TableWidthUnit(TableWidthUnitType.Percent, 20.0f) };

            Paragraph par = new Paragraph();
            par.Inlines.Add(new Span("Image test"));

            cell.Blocks.Add(par);
            row.Cells.Add(cell);

            cell = new TableCell() { PreferredWidth = new TableWidthUnit(TableWidthUnitType.Percent, 80.0f) };
            cell.Blocks.Add(AddImage(null, testImage));
            //cell.Blocks.Add(AddImage(null, testImage, 0.0f));
            row.Cells.Add(cell);

            table.Rows.Add(row);

            section.Blocks.Add(table);
            document.Sections.Add(section);
        }

        static Paragraph AddImage(string imagePath, System.Drawing.Bitmap bitmapImage)
        {   //add image from the assembly resource or from a Bitmap
            try
            {
                ImageInline imageTmp;
                Stream inStream;

                if (String.IsNullOrWhiteSpace(imagePath) == false)
                {
                    inStream = Application.GetResourceStream(new Uri(imagePath, UriKind.RelativeOrAbsolute)).Stream;
                    imageTmp = new ImageInline(inStream);
                }
                else
                {
                    inStream = new MemoryStream();
                    bitmapImage.Save(inStream, ImageFormat.Png);
                    imageTmp = new ImageInline(inStream, new System.Windows.Size(bitmapImage.Width, bitmapImage.Height), "png");
                }

                Paragraph par = new Paragraph();
                par.Inlines.Add(imageTmp);
                inStream = null;
                return (par);
            }
            catch (Exception ex)
            {
                System.Diagnostics.Debug.WriteLine("AddInlinePicture() - exception - " + ex.ToString() + "\n\n");
                throw;
            }
        }

        private static Uri GetResourceUri(string resource)
        {
            AssemblyName assemblyName = new AssemblyName(typeof(MainWindow).Assembly.FullName);
            string resourcePath = "/" + assemblyName.Name + ";component/" + resource;
            Uri resourceUri = new Uri(resourcePath, UriKind.Relative);

            return resourceUri;
        }
    }
}
